function srf = nrb4surf(p11,p12,p21,p22)
// Constructs a NURB surface defined by 4 points to form
// a bilinear surface.
//
//   srf = nrb4srf(p11,p12,p21,p22)
//
// Inputs:
//
//   p11 - 3D coordinate of the corner point
//   p12 - 3D coordinate of the corner point 
//   p21 - 3D coordinate of the corner point 
//   p22 - 3D coordinate of the corner point 
//
//   The position of the corner points
//
//         ^ v direction
//         |
//         ----------------
//         |p21        p22|
//         |              |
//         |    SRF       |
//         |              |
//         |p11        p12|
//         -------------------> u direction
//
// Outputs:
//
//   srf - A bilinear NURB surface defined at 4 points
//          

[nlhs,nrhs] = argn(0);

if nrhs < 4 
  error('Four corner points must be defined'); 
end

coefs = hypermat([4 2 2]);
coefs(4,:,:) = ones(2,2);
coefs(1:length(p11),1,1) = p11(:);    
coefs(1:length(p12),2,1) = p12(:);
coefs(1:length(p21),1,2) = p21(:);
coefs(1:length(p22),2,2) = p22(:);
             
srf = nrbmak(coefs, [0 0 1 1], [0 0 1 1]);
endfunction
