function srf = nrbcylind(height,radius,cntr,sang,eang)
// Construct a cylinder or cylindrical patch by extruding
// a circular arc.
//
//       srf = nrbcylind([height,radius,cntr,sang,eang])
//
// INPUT:
//
//   height - height of the cylinder (default: 1)
//   radius - radius of the cylinder (default: 1)
//   cntr   - center coordinates (default: 0,0,0)
//   sang   - start angle relative to the origin (default: 0)
//   eang   - end angle relative to the origin (default: 2*pi)
//
// Outputs:
//
//   curve  - NURB curve. 

[nlhs,nrhs] = argn();

if nrhs < 1
  height = 1;
end

if nrhs < 2
  radius = 1;
end

if nrhs < 3
  cntr = [];
end
   
if nrhs < 5
  sang = 0;
  eang = 2*pi;
end

srf = nrbextrude(nrbcirc(radius,cntr,sang,eang),[0.0 0.0 height]);
endfunction
