function [pnt,jac,hesn] = nrbdeval(nurb,ders,ut,vt)
// Evaluate NURBS derivative at the parametric points.
//
// INPUTS:
//
//   nurb - original NURBS.
//   ders - NURB derivative curves or surfaces.
//   ut   - parametric evaluation point along U.
//   vt   - paramteric evaluation point along V.
//
// OUTPUTS:
//
//   pnt  - evaluated points.
//   jac  - evaluated first derivatives (Jacobian).
//   hesn - evaluated second derivatives (Hessian).
//
// NOTE:
//
// I'm not 100% happy with this function and nrbderiv, and they will
// probably be changed in the near future. Also the second derivatives
// for NURBS surfaces is not functioning yet!

[nlhs,nrhs] = argn(0);

if nrhs < 2
  error('Incorrect number of input arguments');
end

if type(nurb) ~= 16
  error('NURB representation is not a type list!');
end

if type(ders) ~= 16
  error('NURB derivatives representation is not a type list!');
end

if nurb('vknots') == []
  
  // NURBS is a curve
  [cp,cw] = nrbeval(nurb,ut);
  temp = cw(ones(3,1),:);
  pnt = cp./temp;
  
  // first derivative
  [cup,cuw] = nrbeval(ders('cu'),ut);
  temp1 = cuw(ones(3,1),:);
  jac = (cup-temp1.*pnt)./temp;
  
  // second derivative
  [cuup,cuuw] = nrbeval(ders('cuu'),ut);
  hesn = (cuup-2*temp1.*jac-cuuw(ones(3,1),:).*pnt)./temp;

else 
  
  // NURBS is a surface
  [cp,cw] = nrbeval(nurb,ut,vt);
  temp = cw(ones(3,1),:,:);
  pnt = cp./temp;

  // first derivatives

  jac = hypermat([2 size(pnt)]);
  
  [cup,cuw] = nrbeval(ders('su'),ut,vt);
  tempu = cuw(ones(3,1),:,:);
  jac1 = (cup-tempu.*pnt)./temp;
  jac(1,:,:,:) = jac1;
  
  [cvp,cvw] = nrbeval(ders('sv'),ut,vt);
  tempv = cvw(ones(3,1),:,:);
  jac2 = (cvp-tempv.*pnt)./temp;
  jac(2,:,:,:) = jac2;
  
  // second derivatives (further work required)

//  hessn = hypermat([2 2 size(pnt)]);
  
//  [cuup,cuuw] = nrbeval(ders('suu'),ut,vt);
//  hesn(1,1,:,:,:) = (cuup-2*tempu.*jac1-cuuw(ones(3,1),:,:).*pnt)./temp;

//  [cvvp,cvvw] = nrbeval(ders('svv'),ut,vt);
//  hesn(2,2,:,:,:) = (cvvp-2*tempv.*jac2-cvvw(ones(3,1),:,:).*pnt)./temp;
		     
//  tempuv = tempu.*jac2 + tempv.*jac1;		     
		     
//  [cuvp,cuvw] = nrbeval(ders('suv'),ut,vt);
//  hesn(1,2,:,:,:) = (cuvp-tempuv-cuvw(ones(3,1),:,:).*pnt)./temp;

//  [cvup,cvuw] = nrbeval(ders('svu'),ut,vt);
//  hesn(2,1,:,:,:) = (cvup-tempuv-cvuw(ones(3,1),:,:).*pnt)./temp;
    
end
endfunction

