function srf = nrbextrude(curve,vector)
// Construct a NURBS surface by extruding a NURBS curve along
// the vector (dx,dy,dz).
//
//         srf = nrbextrude(curve,vector)
//
// INPUT:
//
//   curve   - NURBS curve to be extruded.
//   vector  - Extrusion vector.            
//
// OUTPUT:
//
//   srf     - The extruded NURBS surface.
//             The Curve forms the surface edge in the u direction,
//             and is extruded along the vector in the v direction.    
//

[nlhs,nrhs] = argn();

if curve('vknots') ~= []
  error('Nurb surfaces cannot be extruded!');
end

if nrhs < 2
  error('Error too few input arguments!');
end

coefs = hypermat([4 size(curve(3),2) 2]);
coefs(:,:,1) = curve(3);
coefs(:,:,2) = vectrans(vector)*curve(3);
srf = nrbmak(coefs,curve(4),[0 0 1 1]);
endfunction
