function curve = nrbline(p1,p2)
// NURB representation of a 2D or 3D straight line.
//
//   curve = nrbline([p1,p2])
//
// Inputs:
//
//   p1 - 2D or 3D coordinate of the start point
//   p2 - 2D or 3D coordinate of the end point 
//
// Outputs:
//
//   curve - NURB straight line.
//
// Notes:
//
//   If p1 and p2 not included output is a 2D line of
//   unit length along the x-axis.
//

cntrl = [zeros(3,2); ones(1,2)];

[nlhs,nrhs] = argn(0);

if nrhs < 2
  cntrl(1,2) = 1.0;  
else
  cntrl(1:length(p1),1) = p1(:);    
  cntrl(1:length(p2),2) = p2(:);
end

curve = nrbmak(cntrl, [0 0 1 1]);
endfunction
