function nrbplot(nurb,npts,varargin)
// Plot the NURB curve or surface uisng point evaluation.
//
//      nrbplot(nurb,npts,varargin)
//
// INPUT:
//
//   nurb     -  NURB curve or surface.
//   npts     -  Number of evaluation points.
//                 If a surface subd = [up,vp]
//   varargin -  List of options to be passed directly plot routine:
//                 2D curve plotted with plot2d(x,y,varargin(:))
//                 3D curve plotted with param3d(x,y,z,varargin(:))
//                 Surface  plotted with plot3d(x,y,z,varargin(:))
//

[nlhs,nrhs] = argn(0);

if nrhs < 2
  error('Need a NURB to plot and the number of evaluation points!');
end

if nurb('vknots') == []
  // evaluate and plot the 2D NURB curve
  p = nrbeval(nurb,linspace(0.0,1.0,npts));

  if or((p(3,:)>0),2)
    // plot 3D curve
    param3d(p(1,:),p(2,:),p(3,:),varargin(:));
  else
    // plot 2D curve in (z=0 plane)
    plot2d(p(1,:),p(2,:),varargin(:));
  end
else
  // evaluate 
  p = nrbeval(nurb,linspace(0.0,1.0,npts(1)),linspace(0.0,1.0,npts(2)));
  x = matrix(p(1,:,:),npts);
  y = matrix(p(2,:,:),npts);
  z = matrix(p(3,:,:),npts);
 
  // reorganise into rectangular surface patches
  n1 = npts(1);
  n2 = npts(2);
  ind = ones(1,n1-1).*.[0 1 n1+1 n1]+ (1:n1-1).*.[1 1 1 1];
  ind2 = ones(1,n2-1).*.ind+((0:n2-2)*n1).*.ones(ind);
  nx = prod(size(ind2));
  xx = matrix(x(ind2),4,nx/4);
  yy = matrix(y(ind2),4,nx/4);
  zz = matrix(z(ind2),4,nx/4);

  // plot surface
  plot3d(xx,yy,zz,varargin(:));
end

endfunction


