function curve = nrbrect(w,h)
// Construct NURB representation of a rectangle
// in the x-y plane.
// 
//   curve = nrbrect([width, height])
//
// Inputs:
//
//   width  -  width of the rectangle  (default = 1)
//   height -  height of the rectangle (default = 1)
//
// Outputs:
//
//   curve - NURB rectangular curve.
//
// Notes:
//
//   The rectangle is in the x-y plane and the bottom LHS
//   corner is at (0,0,0).
//   

[nlhs,nrhs] = argn(0);

if nrhs < 1
   w = 1;
   h = 1;
end

if nrhs < 2
   h = w;
end

coefs  = [0 w w w w 0 0 0;
          0 0 0 h h h h 0;
          0 0 0 0 0 0 0 0;
          1 1 1 1 1 1 1 1];
knots  = [0 0 0.25 0.25 0.5 0.5 0.75 0.75 1 1];

curve = nrbmak(coefs, knots);

endfunction

