function rnrb = nrbreverse(nrb)
// Reverse the evaluation direction of the NURB curve or surface.
//
// INPUT:
//
//   nrb - nurb curve or surface.  
//
// OUTPUT:
//
//   rnrb - reversed nurb.
//
// NOTES:
//
//   This operation will not change a surfaces normal.
//

[nlhs,nrhs] = argn(0);

if nrhs ~= 1
  error('Incorrect number of input arguments');
end

if nurb('vknots') == []
  // reverse a NURB curve
  rnrb = nrbmak(nrb('cntrl')(:,$:-1:1), 1.0-nrb('uknots')($:-1:1));
else
  // reverse a NURB surface
  coefs = nrb('cntrl')(:,:,$:-1:1);
  rnrb = nrbmak(coefs(:,$:-1:1,:), 1.0-nrb('uknots')($:-1:1),...
                1.0-nrb('vknots')($:-1:1));           
end
endfunction
