function nurb = nrbtform(nurb,tmat)
// Apply the 3D transform matrix to the NURB control points.
//
//      tnurb = nrbtform(nurb,tmat)
//
// Inputs:
//
//   nurb   - B spline representation of NURB spline
//   tmat   - 3D transformation matrix
//
// Output:
//
//   tnurb  - transformed NURB 
//

[nlhs,nrhs] = argn(0);

if nrhs < 2
  error('Not enough input arguments!');
end;

if nurb('vknots') == []
  // NURB is a curve
  nurb(3) = tmat*nurb(3);
else
  // NURB is a surface
  [dim,nu,nv] = size(nurb(3));
  nurb(3) = matrix(tmat*matrix(nurb(3),[dim nu*nv]),[4 nu nv]);
end
endfunction





