function tsrf = nrbtranspose(srf)
// Transpose the NURBs surface, by swapping U and V directions.
//
// INPUT:
//
//   srf - NURBs surface.
//
// OUTPUT:
//
//   tsrf - Transposed surface
//

if srf('vknots') == []
  error(' A NURB curve cannot be transposed.');
end  

// no scilab equivalent for val = permute(val,[1 3 2]);
c = srf('cntrl');
[d,nu,nv] = size(c)
tc = hypermat([4 nv nu]);
tc(1,:,:) = matrix(c(1,:,:),[nu nv])';
tc(2,:,:) = matrix(c(2,:,:),[nu nv])';
tc(3,:,:) = matrix(c(3,:,:),[nu nv])';
tc(4,:,:) = matrix(c(4,:,:),[nu nv])';
tsrf = nrbmak(tc, srf('vknots'), srf('uknots'));
endfunction
